#
# spec file for package python-dj-database-url
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-dj-database-url
Version:        1.3.0
Release:        2.1
Summary:        Utility to use database URLs in Django applications
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/jazzband/dj-database-url
Source:         https://files.pythonhosted.org/packages/source/d/dj-database-url/dj-database-url-%{version}.tar.gz
BuildRequires:  %{python_module Django > 3.2}
BuildRequires:  %{python_module devel >= 3.6}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django > 3.2
Requires:       python-typing_extensions >= 3.10
BuildArch:      noarch
%python_subpackages

%description
This Django utility allows you to utilize the 12factor inspired
DATABASE_URL environment variable to configure Django applications.

The `dj_database_url.config` method returns a Django database connection
dictionary, populated with all the data specified in your URL. There is
also a `conn_max_age` argument to easily enable Django's connection pool.

If you'd rather not use an environment variable, you can pass a URL in directly
instead to ``dj_database_url.parse``.

Supported Databases
-------------------

Support currently exists for PostgreSQL, PostGIS, MySQL, MySQL (GIS),
Oracle, Oracle (GIS), and SQLite.

%prep
%setup -q -n dj-database-url-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/dj_database_url.py
%{python_sitelib}/dj_database_url-%{version}.dist-info
%pycache_only %{python_sitelib}/__pycache__

%changelog
* Mon May  8 2023 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- python-typing_extensions is always required
* Tue Apr 25 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.0:
  * Better error on missing schema
  * Add types
  * 100%% test coverage
  * Avoid duplicating the uses_netloc and schemes lines
  * isort 5.11.4 is broken
  * Throw warning if DATABASE_URL isn't set
  * Fixes #209 - Make conn_max_age optional[int] type
* Thu Dec 22 2022 Torsten Gruner <simmphonie@opensuse.org>
- Update to version 1.2.0
  * Add the ability to add test databases.
  * Improve url parsing and encoding.
  * Fix missing parameter conn_health_check in check function.
- Version 1.1.0
  * Option for connection health checks parameter.
  * Update supported version python 3.11.
  * Code changes, various improvments.
  * Add project links to setup.py
* Sun Jul 31 2022 Torsten Gruner <simmphonie@opensuse.org>
- Update to 1.0.0
  * Add support for cockroachdb.
  * Add support for the offical MSSQL connector.
  * Update License to be compatible with Jazzband.
  * Remove support for Python < 3.5 including Python 2.7
  * Update source code to Black format.
  * Update CI using pre-commit
* Wed Nov 18 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
- Reduce markup, descriptions are still pretty much plaintext,
  not HTML or rst.
* Fri Mar  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.0:
  * Fixes for python3.6
  * ipv6 parsing
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Dec 13 2017 tchvatal@suse.com
- Switch to github url to contain the LICENSE file
* Thu Sep 21 2017 t.gruner@katodev.de
- Initial release 0.4.2
